Documentation and doctests
--------------------------

This directory contains more detailed documentation of the :code:`easycheck` module, in addition to the main README. Most of the files located here (i.e., those having the string "_doctest" in their names) also serve as doctests. You will find here several files:

* `general description <https://github.com/nyggus/easycheck/blob/master/docs/general_description_doctest.rst>`_;
* `examples of using in code <https://github.com/nyggus/easycheck/blob/master/docs/use_in_code_doctest.rst>`_;
* `how to use in testing <https://github.com/nyggus/easycheck/blob/master/docs/use_in_testing_doctest.rst>`_;
* `how to issue warnings <https://github.com/nyggus/easycheck/blob/master/docs/use_with_warnings_doctest.rst>`_;
* `how to catch exceptions instead of raise them <https://github.com/nyggus/easycheck/blob/master/docs/catch_exceptions_doctest.rst>`_;
* `more detailed examples with self-defined functions <https://github.com/nyggus/easycheck/blob/master/docs/use_for_self_defined_functions_doctest.rst>`_;
* `how to use in try-except blocks <https://github.com/nyggus/easycheck/blob/master/docs/use_with_try_doctest.rst>`_.
